function Userresponse = UserResponsewrapped(Parameters,question,width,restriction,conversion,minlengthlimit,maxlengthlimit,font,fontsize)   %pass in a cell array of prompts

% Check for backward-compatibility for old Userresponse calls
if (nargin > 3)
    OldUserresponse(Parameters,question,width, restriction,conversion,minlengthlimit,maxlengthlimit,font,fontsize);
else
    % 2nd input variable in new Userresponse is responsestruct, not question
    responsestruct = question;
    % 3rd input variable in new Userresponse is variable name, not width
    varname = width;
    % copy responsestruct to old variables
    question = responsestruct.question;
    width = responsestruct.width;
    restriction = responsestruct.allowedchars;
    conversion = responsestruct.conversion;
    minlengthlimit = responsestruct.minlength;
    maxlengthlimit = responsestruct.maxlength;
    font = responsestruct.font;
    fontsize = responsestruct.fontsize;
end

% collect a single user response.
%%%%%%%%%Input
% Parameters: Parameterset for this experiment
% question:  line of the user prompt
%  width:  the number of characters before word wrapping
% restriction:  list of characters that are valid for this response
%       if this is null string, allow all chars



%conversion: changes what the subject enters into
%something else on the screen, this is very useful!
%
%Usage 1:if this parameter were {'4','left';'6','right'} then if a subject
%typed 4, they would see 'left' on the screen instead of a 4.
%
%Usage 2:  if this parameter were {-32}, then 32 is subtracted from all
%entered characters.  This converts lower case to uppercase, for example.
%
%Usage 3: {} will disable all conversions.



%minlengthlimit:   Minimum number of characters that must be entered before
%            the user is allowed to press enter
%maxlengthlimit:   Max number of characters that can be entered


%%%%%%%%%%%Output
%currresp:  string containing the final response of the user
%typing:  history of every keypress with timestamps



left_edge = 20;

ListenChar(2);  %Prevent keyboard input from echoing to the MATLAB command window

if(maxlengthlimit ==-1)      %unlimited input length
    maxlengthlimit = 999999;
end


Screen('TextSize',Parameters.window,fontsize);
Screen('TextFont',Parameters.window,font);
currresp = '';

starty = 100;

    [nx, ny, bbox] = DrawFormattedText(Parameters.window, question, left_edge , 50,[0,0,0],width);





%SCREEN('DrawText',Parameters.window,sprintf('%d',count), 100,starty+200,[0,0,0]); %used for debugging


Screen('Flip', Parameters.window);




if(maxlengthlimit == -2)  %exit without waiting for an Enter press

    typing(1,2) = GetSecs;
    typing(1,1) = 0;

else

    if(Parameters.disableinput==0)   %if input is disabled skip it

        inputok = 0;


        %prior to collecting responses, flush the kb buffer, and wait in a loop
        %until its clear, then flush it again!
        FlushEvents('keyDown');
        [ keyIsDown, seconds, keyCode ] = KbCheck;
        while keyIsDown
            [ keyIsDown, seconds, keyCode ] = KbCheck;
        end
        FlushEvents('keyDown');


        %collect input from the user until they press enter
        displaystring = '';
        stopinput = 0;
        count = 0;
        while(stopinput == 0)
            pause(.01)    %give matlab a chance to breathe

            count = count + 1;
             [nx, ny, bbox] = DrawFormattedText(Parameters.window, question, left_edge , 50,[0,0,0],width);



            DrawFormattedText(Parameters.window, displaystring, left_edge , starty+150,[0,0,0],width)


            %SCREEN('DrawText',Parameters.window,sprintf('%d',count), 100,starty+200,[0,0,0]); %used for debugging


            Screen('Flip', Parameters.window);


            thischar = GetChar;    %get a KB char from the buffer
            typing(count,2) = GetSecs;
            typing(count,1) = thischar;    %this is not the best way to get KB input.  Upgrade to KBcheck in near future



            countinput = 0;
            if(thischar == 8)   %backspace
                if(length(currresp) > 1)
                    currresp = currresp(1:(length(currresp)-1));
                else
                    currresp = '';

                end

            elseif ((thischar ==10 | thischar ==13) & length(currresp) >= minlengthlimit) % Enter key, stop input if we have enough characters
                stopinput = 1;
            elseif(size(restriction,1) > 0)    %if there is a restriction parameter, abide by it
                if(max(thischar == restriction) &length(currresp) < maxlengthlimit)
                    countinput = 1;
                end
            elseif(length(currresp) < maxlengthlimit)
                countinput = 1;
            end

            if(countinput)                  %if this input is valid, add it to the response
                currresp = [currresp thischar];
            end

            displaystring = '';
            for(k = 1:length(currresp))  %build the display string out of the current response
                catchvar = 0;
                if(size(conversion,2) > 1)
                    for(conv = 1: size(conversion,1))  %change one into another
                        if(currresp(k) == conversion{conv,1})
                            displaystring = [displaystring conversion{conv,2}];
                            catchvar = 1;
                        end
                    end

                    if(catchvar ==0)
                        displaystring = [displaystring currresp(k)];
                    end

                elseif(size(conversion,2) > 0)   %conversion is a single number, subtract this from the response (usually to convert lower to upper case

                    displaystring = [displaystring currresp(k)+conversion{1}];
                else  %no conversion at all
                    displaystring = [displaystring currresp(k)];
                end
            end

            %this code here means that holding down a key won't produce
            %repeats.... however, it also slows down responding, and I'm not
            %sure it's necessary.

            % FlushEvents('keyDown');
            % [ keyIsDown, seconds, keyCode ] = KbCheck;
            % while keyIsDown
            %     [ keyIsDown, seconds, keyCode ] = KbCheck;
            % end
            % FlushEvents('keyDown');
        end
    else
        currresp = 0;
        typing = 0;
        ListenChar(1)
        return
    end
    
    % save the final response
    eval(sprintf('Responses.%s = currresp', varname));
    % save the typing stream
    eval(sprintf('Responses.%sTyping = typing', varname));
    %Responses.finalresponse = currresp;
    %Responses.finaltyping = typing;
end



